import { Construct } from 'constructs';
import { RemovalPolicy } from 'aws-cdk-lib';
/**
 * Properties of an AWS account
 */
export interface IAccountProps {
    /**
     * The email to use to create the AWS account
     */
    email: string;
    /**
     * The name of the AWS Account
     */
    name: string;
    /**
     * The account type
     */
    type?: AccountType;
    /**
     * The (optional) Stage name to be used in CI/CD pipeline
     */
    stageName?: string;
    /**
     * The (optional) Stage deployment order
     */
    stageOrder?: number;
    /**
     *  List of your services that will be hosted in this account. Set it to [ALL] if you don't plan to have dedicated account for each service.
     */
    hostedServices?: string[];
    /**
     * The potential Organizational Unit Id the account should be placed in
     */
    parentOrganizationalUnitId?: string;
    /**
     * The potential Organizational Unit Name the account should be placed in
     */
    parentOrganizationalUnitName?: string;
    /**
     * The AWS account Id
     */
    id?: string;
    /**
     * RemovalPolicy of the account. See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
     *
     * @default RemovalPolicy.RETAIN
     */
    removalPolicy?: RemovalPolicy;
}
/**
 * The type of the AWS account
 **/
export declare enum AccountType {
    /**
     * The account used to deploy CI/CD pipelines (See [here](https://cs.github.com/?scopeName=bk&scope=repo%3Aawslabs%2Faws-bootstrap-kit&q=AccountType.CICD) for internal usage).
     */
    CICD = "CICD",
    /**
     * Accounts which will be used to deploy Stage environments (staging/prod ...). (See [here](https://cs.github.com/?scopeName=bk&scope=repo%3Aawslabs%2Faws-bootstrap-kit&q=AccountType.STAGE) for internal usage)
    **/
    STAGE = "STAGE",
    /**
     * Sandbox accounts dedicated to developers work.
     */
    PLAYGROUND = "PLAYGROUND"
}
/**
 * An AWS Account
 */
export declare class Account extends Construct {
    /**
     * Constructor
     *
     * @param scope The parent Construct instantiating this account
     * @param id This instance name
     * @param accountProps Account properties
     */
    readonly accountName: string;
    readonly accountId: string;
    readonly accountStageName?: string;
    readonly accountStageOrder?: number;
    constructor(scope: Construct, id: string, accountProps: IAccountProps);
    registerAsDelegatedAdministrator(accountId: string, servicePrincipal: string): void;
}
