import { Construct } from 'constructs';
import { RemovalPolicy, Stack, StackProps } from 'aws-cdk-lib';
import { AccountType } from './account';
import { RootDns } from './dns';
/**
 * AWS Account input details
 */
export interface AccountSpec {
    /**
     * The name of the AWS account
     */
    readonly name: string;
    /**
     * The (optional) id of the account to reuse, instead of creating a new account
     */
    readonly existingAccountId?: string;
    /**
     * The email associated to the AWS account
     */
    readonly email?: string;
    /**
     * The account type
     */
    readonly type?: AccountType;
    /**
     * The (optional) Stage name to be used in CI/CD pipeline
     */
    readonly stageName?: string;
    /**
     * The (optional) Stage deployment order
     */
    readonly stageOrder?: number;
    /**
     *  List of your services that will be hosted in this account. Set it to [ALL] if you don't plan to have dedicated account for each service.
     */
    readonly hostedServices?: string[];
    /**
     * RemovalPolicy of the account (wether it must be retained or destroyed).
     * See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options
     *
     * As an account cannot be deleted, RETAIN is the default value.
     *
     * If you choose DESTROY instead (default behavior of CloudFormation), the stack deletion will fail and
     * you will have to manually remove the account from the organization before retrying to delete the stack:
     * https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_remove.html
     *
     * Note that existing accounts (when using `existingAccountId`) are retained whatever the removalPolicy is.
     *
     * @default RemovalPolicy.RETAIN
     */
    readonly removalPolicy?: RemovalPolicy;
}
/**
 * Organizational Unit Input details
 */
export interface OUSpec {
    /**
     * Name of the Organizational Unit
     */
    readonly name: string;
    /**
     * Accounts' specification inside in this Organizational Unit
     */
    readonly accounts?: AccountSpec[];
    /**
     * Specification of sub Organizational Unit
     */
    readonly nestedOU?: OUSpec[];
}
/**
 * Properties for AWS SDLC Organizations Stack
 * @experimental
 */
export interface AwsOrganizationsStackProps extends StackProps {
    /**
     * Email address of the Root account
     */
    readonly email: string;
    /**
     * Specification of the sub Organizational Unit
     */
    readonly nestedOU: OUSpec[];
    /**
     * The main DNS domain name to manage
     */
    readonly rootHostedZoneDNSName?: string;
    /**
     * The (optional) existing root hosted zone id to use instead of creating one
     */
    readonly existingRootHostedZoneId?: string;
    /**
     * A boolean used to decide if domain should be requested through this delpoyment or if already registered through a third party
     */
    readonly thirdPartyProviderDNSUsed?: boolean;
    /**
    * Enable Email Verification Process
    */
    readonly forceEmailVerification?: boolean;
}
/**
 * A Stack creating the Software Development Life Cycle (SDLC) Organization
 */
export declare class AwsOrganizationsStack extends Stack {
    private readonly emailPrefix?;
    private readonly domain?;
    private readonly stageAccounts;
    readonly rootDns?: RootDns;
    private createOrganizationTree;
    constructor(scope: Construct, id: string, props: AwsOrganizationsStackProps);
}
